PORTA	EQU	$1000
PORTB	EQU	$1004		    ;Port B
PORTC	EQU	$1003		    ;Port C
PORTD	EQU	$1008		    ;Port D

DDRC	EQU	$1007		    ;Port C ,data direction reg
DDRD	EQU	$1009		    ;Port D ,data direction reg
TCTL1	EQU	$1020		    ;timer control reg 1
TMSK1	EQU	$1022		    ;timer mask reg 1
TFLG1	EQU	$1023		    ;timer flag reg 1
TCNT	EQU	$100E		    ;timer counter reg
TOC2	EQU	$1018		    ;output compare reg 2
ADCTL	EQU	$1030		    ;ADC control reg
ADR1	EQU	$1031		    ;ADC data loc 1
ADR2	EQU	$1032		    ;ADC data loc 2
ADR3	EQU	$1033		    ;ADC data loc 3
ADR4	EQU	$1034		    ;ADC data loc 4

BPROT	EQU	$1035		    ;block protect register


BAUD	EQU	$102B		    ;serial baud register
SCCR1	EQU	$102C		    ;serial control register 1
SCCR2	EQU	$102D		    ;serial control register 2
SCSR	EQU	$102E		    ;serial status register
SCDR	EQU	$102F		    ;serial tx/rx data register

OPTION	EQU	$1039
PPROG	EQU	$103B
INIT	EQU	$103D
CONFIG	EQU	$103F
*
*	code start
*

	ORG	$0000

RESET:
	LDS	#$00FF		    ;Set up stack ,to be top of ram

	LDAA	#$13
	STAA	OPTION

	CLR	BPROT

*
*	initialise the serial port for polling,8data,1stop,1200
*
	LDAA	#$30		;prescaler const for 1200 baud
	STAA	BAUD

	LDAA	#$00
	STAA	SCCR1		;select 8 data

	LDAA	#$0C		;enable tx rx ers
	STAA	SCCR2

*
*	bulk erase of eeprom
*

	LDX	#$07D0		;2000 steps = 10mS	charge pump time
ER11	DEX
	BNE	ER11

	LDAB	#$06		;all,row=0,erase=1,eelat=1,voltage=off
	STAB	PPROG		;prepare to erase
	STAB	$F800		;latch add / erase config,bulkall
	LDAB	#$07		;prepare to turn voltage on
	STAB	PPROG
	BSR	DEL10
	CLR	PPROG

*
*	configure CONFIG to $0D NOSEC=1,NOCOP=1,ROMON=0,EEON=1
*
	LDAA	#$0D		;data for CONFIG

	LDAB	#$02		;turn on EELAT
	STAB	PPROG
	STAA	CONFIG		;write to config
	INCB			;to $03 turns on EEGPM bit
	STAB	PPROG
	BSR	DEL10		;wait 10mS
	CLR	PPROG

*
*	initialise constants
*

	LDX	#$9876 		;beginning of the EEPROM

*
*	get a hex number
*

CONT	LDAA	SCSR		;get a copy of the status register
	ANDA	#$20		;mask out the rx full bit
	BEQ	CONT		;continue until data is ready

	LDAA	SCDR		;Read byte

*
*	burn character into appropriate location in EEPROM
*	if it is not FF
*

	CMPA	#$FF
	BEQ	SND1		;skip because no burning necessary

	LDAB	#$02		;erase=0,eelat=1,eepgm=0
	STAB	PPROG		;set up burn parameters

	STAA	0,X		;write data into desired loc

	LDAB	#$03		;prepare to turn on prog voltage
	STAB	PPROG		;turn it on

	BSR	DEL10

	CLR	PPROG		;restore

*
*	reply with the character only when finished
*

SND1	LDAB	SCSR		;prepare to chect tx flag
	ANDB	#$80		;AND out flag
	BEQ	SND1		;wait until tx reg empty

	LDAA	0,X		;get value programmed for reply
	STAA	SCDR		;send the result of the burn
	INX			;advance the pointer to the next loc

	BRA	CONT		;continue while there is data

*
*
DEL10:
	PSHX
	LDX	#$07D0		;2000(0x07D0)@8MHz
ER1	DEX
	BNE	ER1
	PULX
	RTS

	END

